# LocalPy
### A simple app for saving secrets locally and securely.

## Before Install
### Install Python3.7+ (add to PATH)
#### https://www.python.org/downloads/
### Upgrade pip
#### python -m pip install --upgrade pip

## Installation
#### python -m pip install localpy==1.0.2

## Run App
#### python -m localpy

